@@ -76,7 +76,7 @@ class Config:
         """Конфигурация по умолчанию"""
         return {
             "version": "1.0.0",
-            "api_endpoint": "http://localhost:15080",
+            "api_endpoint": "https://cli.durusai.com",
             "default_profile": "default",
             "settings": {
                 "timeout": 30,
@@ -85,7 +85,7 @@ class Config:
                 "cache_ttl": 3600,
                 "auto_update": True,
                 "show_token_usage": True,
-                "default_model": "unified-ai-team",
+                "default_model": "durusai",
                 "max_history_size": 1000
             },
             "display": {
@@ -134,7 +134,7 @@ class Config:
     
     def get_api_endpoint(self) -> str:
         """Получить API endpoint"""
-        return self.get("api_endpoint", "http://localhost:8080")
+        return self.get("api_endpoint", "https://cli.durusai.com")
     
     def set_api_endpoint(self, endpoint: str):
         """Установить API endpoint"""
