@@ -17,6 +17,7 @@ import sys
 from .config import Config
 from .api_client import SyncDurusAIClient
 from .exceptions import AuthenticationError, NetworkError
+from .local_file_ops import LocalFileOperations, detect_file_command, format_file_list, extract_project_structure
 
 
 class InteractiveMode:
@@ -36,6 +37,9 @@ class InteractiveMode:
             "total_tokens": 0
         }
         
+        # Локальные файловые операции
+        self.file_ops = LocalFileOperations()
+        
         # Стиль для prompt_toolkit
         self.style = Style.from_dict({
             'prompt': '#00aa00 bold',
@@ -252,10 +256,211 @@ class InteractiveMode:
         except Exception as e:
             self.console.print(f"❌ Ошибка экспорта: {e}", style="red")
     
+    def handle_file_command(self, file_command: Dict[str, Any]):
+        """Обработать файловую команду локально"""
+        command = file_command["command"]
+        args = file_command["args"]
+        
+        try:
+            if command == "pwd":
+                current_dir = self.file_ops.pwd()
+                self.console.print(f"📁 Текущая директория: [cyan]{current_dir}[/cyan]")
+            
+            elif command == "ls":
+                show_details = "-la" in args or "-lah" in args or "-al" in args
+                path = None
+                
+                # Извлекаем путь из аргументов
+                for arg in args:
+                    if not arg.startswith('-'):
+                        path = arg
+                        break
+                
+                files_info = self.file_ops.ls(path, show_hidden=show_details)
+                formatted_output = format_file_list(files_info)
+                self.console.print(formatted_output)
+            
+            elif command == "cd":
+                if not args:
+                    self.console.print("❌ Укажите директорию для перехода", style="red")
+                    return
+                
+                result = self.file_ops.cd(args[0])
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "mkdir":
+                if not args:
+                    self.console.print("❌ Укажите имя директории", style="red")
+                    return
+                
+                result = self.file_ops.mkdir(args[0], parents=True)
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "cat":
+                if not args:
+                    self.console.print("❌ Укажите имя файла", style="red")
+                    return
+                
+                result = self.file_ops.cat(args[0])
+                if result.get("success"):
+                    self.console.print(f"📄 [cyan]{result['file_path']}[/cyan]:")
+                    self.console.print(Panel(result["content"], border_style="blue"))
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "tree":
+                path = args[0] if args else None
+                result = self.file_ops.tree(path)
+                if result.get("success"):
+                    self.console.print(result["tree"])
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "rm":
+                if not args:
+                    self.console.print("❌ Укажите путь для удаления", style="red")
+                    return
+                
+                result = self.file_ops.rm(args[0], recursive=True)
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "cp":
+                if len(args) < 2:
+                    self.console.print("❌ Укажите источник и назначение", style="red")
+                    return
+                
+                result = self.file_ops.cp(args[0], args[1])
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "mv":
+                if len(args) < 2:
+                    self.console.print("❌ Укажите источник и назначение", style="red")
+                    return
+                
+                result = self.file_ops.mv(args[0], args[1])
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+            
+            elif command == "create_project":
+                # Для команд создания проектов используем AI, но с контекстом локальной директории
+                query = args[0] if args else ""
+                current_dir = self.file_ops.pwd()
+                
+                self.console.print("🤖 [dim]Генерирую код локально...[/dim]")
+                
+                # Формируем запрос с контекстом локальной работы
+                local_prompt = f"""ВАЖНО: Ты работаешь как Claude Code - создавай файлы локально в текущей директории пользователя.
+
+Текущая директория пользователя: {current_dir}
+
+ИНСТРУКЦИЯ: Создай файлы локально используя обычные команды создания файлов. НЕ используй Docker или контейнеры.
+
+Пользователь просит: {query}
+
+Создай проект прямо в текущей директории пользователя."""
+
+                # Отправляем запрос к AI
+                result = self.client.query(
+                    prompt=local_prompt,
+                    model=self.current_model
+                )
+                
+                # Показываем AI ответ
+                response = result["response"]
+                try:
+                    self.console.print(Markdown(response))
+                except:
+                    self.console.print(response)
+                
+                # Проверяем, есть ли файлы для создания в ответе
+                project_structure = extract_project_structure(response)
+                
+                if project_structure['has_project']:
+                    self.console.print("\n🔧 [yellow]Создаю файлы локально...[/yellow]")
+                    
+                    # Создаем директории
+                    for dir_name in project_structure['directories']:
+                        result_dir = self.file_ops.mkdir(dir_name, parents=True)
+                        if result_dir.get("success"):
+                            self.console.print(f"✅ Создана директория: [cyan]{dir_name}[/cyan]")
+                        else:
+                            self.console.print(f"⚠️ Директория {dir_name}: {result_dir.get('error', 'уже существует')}")
+                    
+                    # Создаем файлы
+                    for file_info in project_structure['files']:
+                        filename = file_info['filename']
+                        content = file_info['content']
+                        
+                        # Если есть директория проекта, создаем файл в ней
+                        if project_structure['directories']:
+                            project_dir = project_structure['directories'][0]
+                            file_path = f"{project_dir}/{filename}"
+                        else:
+                            file_path = filename
+                        
+                        result_file = self.file_ops.write_file(file_path, content)
+                        if result_file.get("success"):
+                            self.console.print(f"✅ Создан файл: [green]{file_path}[/green]")
+                        else:
+                            self.console.print(f"❌ Ошибка создания {file_path}: {result_file.get('error')}")
+                    
+                    self.console.print(f"\n🎉 [green]Проект создан локально в директории: {self.file_ops.pwd()}[/green]")
+                
+                # Обновляем статистику
+                tokens_used = result.get("tokens_used", {}).get("total", 0)
+                model_used = result.get("model_used", self.current_model)
+                
+                self.session_stats["queries"] += 1
+                self.session_stats["total_tokens"] += tokens_used
+                
+                if tokens_used > 0:
+                    self.console.print(f"\n[dim]Токены: {tokens_used} | Модель: {model_used}[/dim]")
+                
+                return True
+            
+            elif command == "write":
+                if len(args) < 2:
+                    self.console.print("❌ Укажите содержимое и имя файла", style="red")
+                    return
+                
+                content = args[0]
+                filename = args[1]
+                
+                result = self.file_ops.write_file(filename, content)
+                if result.get("success"):
+                    self.console.print(f"✅ {result['message']}", style="green")
+                else:
+                    self.console.print(f"❌ {result['error']}", style="red")
+        
+        except Exception as e:
+            self.console.print(f"❌ Ошибка выполнения команды: {e}", style="red")
+    
     def handle_query(self, query: str):
         """Обработать пользовательский запрос"""
         try:
-            # Отправляем запрос
+            # Проверяем, является ли запрос файловой командой
+            file_command = detect_file_command(query)
+            
+            if file_command:
+                # Выполняем файловую операцию локально
+                self.handle_file_command(file_command)
+                return True
+            
+            # Если не файловая команда, отправляем к AI
             self.console.print("🤖 [dim]Обработка запроса...[/dim]")
             
             result = self.client.query(
